package com.gic.finance.util.cashwithdrawal.event;

import com.gic.api.base.commons.ServiceResponse;
import com.gic.enterprise.error.ErrorCode;
import com.gic.enterprise.utils.AsyncCallbackUtils;
import com.gic.finance.constant.WithdrawalStatusEnum;
import com.gic.finance.dto.CashWithdrawalDTO;
import com.gic.finance.entity.TabCashWithdrawal;
import com.gic.finance.entity.TabPayAccount;
import com.gic.finance.service.CashWithdrawalService;
import com.gic.finance.service.PayAccountService;
import com.gic.finance.util.cashwithdrawal.State;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Date;

/**
 * 审批通过状态
 * @ClassName: ApprovalState 
 * @Description:  
 * @author guojuxing 
 * @date 2020/11/6 11:19 AM 
 */
@Component
public class ApprovalState extends State{

    @Autowired
    private CashWithdrawalService cashWithdrawalService;
    @Autowired
    private PayAccountService payAccountService;

    @Override
    public ServiceResponse<String> cashWithdrawal(CashWithdrawalDTO dto) {
        return ServiceResponse.failure(ErrorCode.SYSTEM_ERROR.getCode(), "已通过审批");
    }

    @Override
    public ServiceResponse<Void> approval(TabCashWithdrawal record) {
        return ServiceResponse.failure(ErrorCode.SYSTEM_ERROR.getCode(), "已通过审批");
    }

    @Override
    public ServiceResponse<Void> reject(TabCashWithdrawal record) {
        return ServiceResponse.failure(ErrorCode.SYSTEM_ERROR.getCode(), "已通过审批");
    }

    @Override
    public ServiceResponse<Void> cancel(TabCashWithdrawal record) {
        return ServiceResponse.failure(ErrorCode.SYSTEM_ERROR.getCode(), "已通过审批");
    }

    @Override
    public ServiceResponse<Void> complete(TabCashWithdrawal record) {
        if (StringUtils.isBlank(record.getBankSerialNumber())) {
            return ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "银行流水号不能为空");
        }
        TabPayAccount account = payAccountService.getById(record.getPayId());
        if (account == null) {
            return ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "无此打款户信息记录，请前往添加");
        }
        //todo 操作人相关信息
        record.setOperatorTime(new Date());

        record.setPayId(record.getPayId());
        record.setPayAccount(account.getBankAccount());
        record.setPayAccountBank(account.getBank());
        record.setPayAccountBranchName(account.getBranchName());
        record.setPayAccountName(account.getAccountName());
        record.setCashWithdrawalStatus(WithdrawalStatusEnum.COMPLETE.getCode());
        cashWithdrawalService.update(record);

        //回调
        AsyncCallbackUtils.callBack(record, "com.gic.open.api.service.market.PayCallbackApiService", "callbackWithdraw");
        return ServiceResponse.success();
    }
}
