package com.gic.finance.util.cashwithdrawal.event;

import com.gic.api.base.commons.ServiceResponse;
import com.gic.enterprise.error.ErrorCode;
import com.gic.enterprise.utils.CreateRandomUtils;
import com.gic.enterprise.utils.valid.ValidParamsUtils;
import com.gic.finance.constant.WithdrawalStatusEnum;
import com.gic.finance.dto.CashWithdrawalDTO;
import com.gic.finance.entity.TabCashWithdrawal;
import com.gic.finance.service.CashWithdrawalService;
import com.gic.finance.util.cashwithdrawal.State;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Date;
/**
 * 新增提审
 * @ClassName: CashWithdrawalState 
 * @Description:  
 * @author guojuxing 
 * @date 2020/11/6 4:51 PM 
 */
@Component
public class CashWithdrawalState extends State{
    @Autowired
    private CashWithdrawalService cashWithdrawalService;

    @Override
    public ServiceResponse<String> cashWithdrawal(CashWithdrawalDTO dto) {
        ServiceResponse paramValid = ValidParamsUtils.allCheckValidate(dto, CashWithdrawalDTO.CashWithdrawal.class);
        if (!paramValid.isSuccess()) {
            return paramValid;
        }
        dto.setCreateTime(new Date());
        dto.setUpdateTime(new Date());
        dto.setCashWithdrawalStatus(WithdrawalStatusEnum.TO_BE_EXAMINE.getCode());
        //流水号
        dto.setCashWithdrawalSerialNumber(CreateRandomUtils.createSerialNumber());
        cashWithdrawalService.save(dto);
        return ServiceResponse.success(dto.getCashWithdrawalSerialNumber());
    }

    @Override
    public ServiceResponse<Void> approval(TabCashWithdrawal record) {
        return ServiceResponse.failure(ErrorCode.SYSTEM_ERROR.getCode(), "提审中，不能通过审批");
    }

    @Override
    public ServiceResponse<Void> reject(TabCashWithdrawal record) {
        return ServiceResponse.failure(ErrorCode.SYSTEM_ERROR.getCode(), "提审中，不能拒绝审批");
    }

    @Override
    public ServiceResponse<Void> cancel(TabCashWithdrawal record) {
        return ServiceResponse.failure(ErrorCode.SYSTEM_ERROR.getCode(), "提审中，不能取消审批");
    }

    @Override
    public ServiceResponse<Void> complete(TabCashWithdrawal record) {
        return ServiceResponse.failure(ErrorCode.SYSTEM_ERROR.getCode(), "提审中，不能打款");
    }
}
